==> haskell-hls-call-hierarchy-plugin-1.2.0.0-237-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-call-hierarchy-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-call-hierarchy-plugin
version:              1.2.0.0
visibility:           public
id:                   hls-call-hierarchy-plugin-1.2.0.0-8pgXNOakmFFKqaDjAco4zQ
key:                  hls-call-hierarchy-plugin-1.2.0.0-8pgXNOakmFFKqaDjAco4zQ
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Call hierarchy plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-call-hierarchy-plugin#readme>

category:             Development
abi:                  408deef8168d9612a38235d752c4a171
exposed:              True
exposed-modules:      Ide.Plugin.CallHierarchy
hidden-modules:
    Ide.Plugin.CallHierarchy.Internal Ide.Plugin.CallHierarchy.Query
    Ide.Plugin.CallHierarchy.Types

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-call-hierarchy-plugin-1.2.0.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-call-hierarchy-plugin-1.2.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-call-hierarchy-plugin
hs-libraries:         HShls-call-hierarchy-plugin-1.2.0.0-8pgXNOakmFFKqaDjAco4zQ
depends:
    aeson-2.1.2.1-7IgTEIjsesxDBKStPrg8Ee base-4.16.4.0
    containers-0.6.5.1 extra-1.7.16-CDnJ4IIZiy49QmNU3HquQ1
    ghcide-1.10.0.0-LUOZfaZsPo92GAjJrHasb
    hiedb-0.4.3.0-Aluk0R0dj0r5HaZhkT2gIu
    hls-plugin-api-1.6.0.0-IlaR5sSrdwK8yu9HE27Hij
    lens-5.2.3-3BG1BTsYajWH51jWMi4vYO
    lsp-1.6.0.0-DT4gnHhljAEFkxKkAe5FzR
    sqlite-simple-0.4.19.0-9Uq8ai0mWT6JFklxE6NoZx text-1.2.5.0
    unordered-containers-0.2.20-4c1XIGAoQE4JZSLkR4PXOi

haddock-interfaces:
    /usr/share/doc/haskell-hls-call-hierarchy-plugin/html/hls-call-hierarchy-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-call-hierarchy-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-call-hierarchy-plugin-1.2.0.0-238-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-call-hierarchy-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-call-hierarchy-plugin
version:              1.2.0.0
visibility:           public
id:                   hls-call-hierarchy-plugin-1.2.0.0-ITuCkDHOBfTFc5onpzxZG4
key:                  hls-call-hierarchy-plugin-1.2.0.0-ITuCkDHOBfTFc5onpzxZG4
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Call hierarchy plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-call-hierarchy-plugin#readme>

category:             Development
abi:                  463385dfaeee4172d5531fb53162d6e8
exposed:              True
exposed-modules:      Ide.Plugin.CallHierarchy
hidden-modules:
    Ide.Plugin.CallHierarchy.Internal Ide.Plugin.CallHierarchy.Query
    Ide.Plugin.CallHierarchy.Types

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-call-hierarchy-plugin-1.2.0.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-call-hierarchy-plugin-1.2.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-call-hierarchy-plugin
hs-libraries:         HShls-call-hierarchy-plugin-1.2.0.0-ITuCkDHOBfTFc5onpzxZG4
depends:
    aeson-2.1.2.1-HbpdIbO6AMR9AnrzgnqgHA base-4.16.4.0
    containers-0.6.5.1 extra-1.7.16-LvCisaJe0r84H5u45TnjVU
    ghcide-1.10.0.0-JAYr5u0LqJB5oiYVxdFyXE
    hiedb-0.4.3.0-WXEqbE56XWBUTsE894gpS
    hls-plugin-api-1.6.0.0-G7p1SsZyfJjFQU1Rh4InUp
    lens-5.2.3-8lYAGRbsVBB5Dn410nzJey
    lsp-1.6.0.0-K5sMJCq0XCfJihpkwmS2i0
    sqlite-simple-0.4.19.0-BEqluXRTdvDA824QzzjwpK text-1.2.5.0
    unordered-containers-0.2.20-FlJ58vN39MpAJvDCdrVy2C

haddock-interfaces:
    /usr/share/doc/haskell-hls-call-hierarchy-plugin/html/hls-call-hierarchy-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-call-hierarchy-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
